@@ -5,9 +5,11 @@
 import asyncio
 import logging
 import os
+import re
 import sys
 import time
 import requests
+import math
 
 import aria2p
 from pyrogram.errors import FloodWait, MessageNotModified
@@ -20,6 +22,8 @@ from tgtlg import (
     EDIT_SLEEP_TIME_OUT,
     LOGGER,
     MAX_TIME_TO_WAIT_FOR_TORRENTS_TO_START,
+    FINISHED_PROGRESS_STR,
+    UN_FINISHED_PROGRESS_STR
 )
 from tgtlg.helper_funcs.create_compressed_archive import (
     create_archive,
@@ -324,12 +328,18 @@ async def check_progress_for_dl(aria2, gid, event, previous_message):
                     pass
                 #
                 if is_file is None:
-                    msgg = f"<b>Connections : {file.connections} </b>"
+                    msgg = f"<b>Connections: {file.connections} </b>"
                 else:
                     msgg = f"<b>P: {file.connections}\nS: {file.num_seeders} </b>\n\n<b>GID:</b> <code>{gid}</code>"
+                    
+                dnld_complete = round(float(re.sub("[^0-9.]", "", file.total_length_string())) * (float(re.sub("[^0-9.]", "", file.progress_string()))/100),2)
+                percentage = int(file.progress_string(0).split('%')[0])
+                prog = "[{0}{1}]".format("".join([FINISHED_PROGRESS_STR for i in range(math.floor(percentage / 5))]),"".join([UN_FINISHED_PROGRESS_STR for i in range(20 - math.floor(percentage / 5))]))
+                
                 msg = f"\n<b>File name:</b> `{downloading_dir_name}`\n\n<b>Speed:</b> `{file.download_speed_string()}`"
                 msg += f"\n<b>Size:</b> `{file.total_length_string()}`"
-                msg += f"\n<b>Downloaded</b>: `{file.progress_string()}` \n<b>ETA:</b> `{file.eta_string()}` \n {msgg}"
+                msg += f"\n<b>{prog}</b>
+                msg += f"\n<b>Downloaded</b>: `{dnld_complete} of {file.progress_string()}` \n<b>ETA:</b> `{file.eta_string()}` \n {msgg}"
                 inline_keyboard = []
                 ikeyboard = []
                 ikeyboard.append(
